if(!self.define){let e,i={};const s=(s,n)=>(s=new URL(s+".js",n).href,i[s]||new Promise(i=>{if("document"in self){const e=document.createElement("script");e.src=s,e.onload=i,document.head.appendChild(e)}else e=s,importScripts(s),i()}).then(()=>{let e=i[s];if(!e)throw new Error(`Module ${s} didn’t register its module`);return e}));self.define=(n,r)=>{const o=e||("document"in self?document.currentScript.src:"")||location.href;if(i[o])return;let l={};const c=e=>s(e,o),t={module:{uri:o},exports:l,require:c};i[o]=Promise.all(n.map(e=>t[e]||c(e))).then(e=>(r(...e),l))}}define(["./workbox-2fbc6a65"],function(e){"use strict";self.addEventListener("message",e=>{e.data&&"SKIP_WAITING"===e.data.type&&self.skipWaiting()}),e.precacheAndRoute([{url:"styles.css",revision:"8360d11a26c5363505387e21b790470e"},{url:"index.html",revision:"66827b539fb3fb0143184b90dc924c32"},{url:"assets/workbox-window.prod.es5-Cch4wiA5.js",revision:null},{url:"assets/index-mpix2PMe.js",revision:null},{url:"assets/index-Dpy-g0Ki.css",revision:null},{url:"assets/alarm-DM0YUa2r.mp3",revision:null},{url:"apple-touch-icon-180x180.png",revision:"27527b05315b4bcaa27183d0c99178d6"},{url:"favicon.ico",revision:"03d55280cc7e16907f90d7d152111869"},{url:"pwa-192x192.png",revision:"3b1e4bbecc729dd5ba5c67eb273f91ee"},{url:"pwa-512x512.png",revision:"9e98c5c9167e3577609ac44b27c5be45"},{url:"pwa-64x64.png",revision:"bb08d4ffe204a919b06960e1a96caea7"},{url:"manifest.webmanifest",revision:"ed5f9c3cb487e7734d3bd928d7f4fe17"}],{}),e.cleanupOutdatedCaches(),e.registerRoute(new e.NavigationRoute(e.createHandlerBoundToURL("index.html"),{denylist:[/^\/api/]}))});
